@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -47,6 +47,9 @@ class InstallLinux(Linux, VariableInterface):
         """Get by distroinfo or current info"""
         return self.__getFromImageOrCurrent(self.current_variable)
 
+class VariableOsInstallChrootableSet(InstallLinux, ReadonlyVariable):
+    """Можно ли выполнить chroot в систему"""
+    current_variable = "os_chrootable_set"
 
 class VariableOsInstallLinuxShortname(InstallLinux, ReadonlyVariable):
     """Shortname of system"""
